//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APU101
// Target Platform : Linux, C
// Date            : July 2017
// Version         : 1.0
//*****************************************************************************
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "file.h"


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in in_cps   : input count rate(cps)
//      in th_cps   : throughput count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(char *pName, unsigned int now_time,
                      unsigned int in_cps, unsigned int th_cps)
{
    FILE *fp;

    // open file(create)
    fp = fopen(pName, "wt");
    if (fp == NULL) {
        return(-1);
    }

    // write header information
    fprintf(fp, "[header]\n");
    fprintf(fp, "Real time(s), %d\n", now_time/1000);
    fprintf(fp, "Input rate(cps), %d\n", in_cps);
    fprintf(fp, "Throughput rate(cps), %d\n", th_cps);

    // close file
    fclose(fp);

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in nbyte : size of the data(byte)
//      in pBuff : pointer to the data buffer
//  Return :
//       0 : success
//      -1 : failed to open file
//      -2 : failed to seek
//#########################################################################
int file_write_data(char *pName, int nbyte, void *pBuff)
{
    FILE *fp;
    int  ret;
    int  i;
    unsigned int *p;
    int unit = nbyte;

    // open file(append)
    fp = fopen(pName, "rt+");
    if (fp == NULL) {
        return(-1);
    }

    // move to end of the file
    ret = fseek(fp, (int)0, SEEK_END);
    if (ret != 0) {
        fclose(fp);
        return(-2);
    }

    // write data
    p = (unsigned int *)pBuff;
    unit = nbyte / sizeof(unsigned int);

    fprintf(fp, "[data]\n");
    for (i = 0; i < unit; i++, p++) {
        fprintf(fp, "%d\n", *p);
    }

    // close file
    fclose(fp);

    return(i);
}
